@@ -137,12 +137,14 @@ def encode_pdf_date(d: datetime) -> str:
     considered unknown. Regardless of whether or not GMT
     information is specified, the remainder of the string should specify
     the local time.
+
+    'D:' is required in PDF/A, so we always add it.
     """
 
     # The formatting of %Y is not consistent as described in
     # https://bugs.python.org/issue13305 and underspecification in libc.
     # So explicitly format the year with leading zeros
-    s = f"{d.year:04d}"
+    s = f"D:{d.year:04d}"
     s += d.strftime(r'%m%d%H%M%S')
     tz = d.strftime('%z')
     if tz:
